package App::csv2tsv ;  
our $VERSION = '0.581' ; 
our $DATE = '2021-06-11T23:02+09:00' ; 

=encoding utf8

=head1 NAME

App::csv2tsv

=head1 SYNOPSIS

This module provides a Unix-like command `F<csv2tsv>'. 
Usage : csv2tsv < input.csv > output.tsv 


=head1 DESCRIPTION



=head1 SEE ALSO


=cut

1 ;
